" Vim syntax file
" Language:	HTML with HSC
" Maintainer:	Matthias Bethke <matthias.bethke@gmx.net>
" URL: 
" Last Change:	2002 Oct 10

" For version 5.x: Clear all syntax items
" For version 6.x: Quit when a syntax file was already loaded
if version < 600
  syntax clear
elseif exists("b:current_syntax")
  finish
endif

" Same as for HTML
if version < 508
  command! -nargs=+ HscHiLink hi link <args>
else
  command! -nargs=+ HscHiLink hi def link <args>
endif

" we define it here so that included files can test for it
if !exists("main_syntax")
  let main_syntax='htmlhsc'
endif

if version < 600
  so <sfile>:p:h/html.vim
else
  runtime! syntax/html.vim
endif
unlet b:current_syntax

syntax case ignore
syntax sync minlines=150 maxlines=500
"syn cluster htmlPreproc add=@hscTop
setlocal iskeyword+=$,-

"-------------------------------------------------------------------------------
" Additional comments that will be stripped by HSC
syn region  hscComment start="<\*" end="\*>"

" Verbatim data
syn region  hscVerbatimR matchgroup=hscVerbatim start="<|" end="|>"

" Single- and double-quoted strings
syn match  hscString contained #"[^"]*"\|'[^']'#

" Unary and binary operators
syn keyword hscOperator contained basename chr defined exists extension fexists
syn keyword hscOperator contained getenv getfilesize getgmtime gettime not ord
syn keyword hscOperator contained set urikind
syn match   hscOperator contained "[-_&+*/<>=]"
syn match   hscOperator contained "mod\|<=\|>=\|==\|lt\|gt\|le\|ge\|and\|or\|xor"

" A complete HSC expression
syn region  hscExpr start="(" end=")" contains=hscExpr,hscString,hscOperator

" Attributes
syn match   hscSrcAttr  contained "\w[-\.\w]*"    " Source only
syn match   hscAttr     contained "\w[-\.\w]*"
syn match   hscAttr     contained "\w[-\.\w]*?=" nextgroup=hscSrcAttr
syn match   hscAttr     contained "\w[-\.\w]*=" nextgroup=hscExpr,hscString skipwhite skipempty

" An attribute definition as in $macro or $define
syn match   hscAttrDef  contained #\w[-\.\w]*:\a\+\(/\a\+\)*\(=\("[^"]*"\|'[^']*'\)\)\?# contains=hscAttrD,hscModifier,hscDefValue
syn match   hscAttrD    contained "\w[-\w]*:\a\+" contains=hscAttr,hscType
syn match   hscType     contained ":\a\+" nextgroup=hscModifier,hscDefValue
syn match   hscModifier contained "/\a\+" nextgroup=hscDefValue
syn match   hscDefValue contained "=" nextgroup=hscString,hscExpr

" Normal HSC tags starting with $
syn region  hscNormalTagR matchgroup=hscNormalTag start="<\$\(content\|defent\|deficon\|depend\|else\|elseif\|exec\|export\|if\|include\|let\|message\|stripws\)" end=">" contains=hscAttr

" The $macro/$varlist tags
syn region  hscMacroTagR matchgroup=hscNormalTag start="<\$\(macro\|varlist\)" end=">" contains=hscAttrDef,hscAttr,hscModifier

" $define and $deftag -- these take attributes with types
syn region  hscDefTagR matchgroup=hscDefTag start="<$\(define\|deftag\)" end=">" contains=hscAttrDef,hscModifier

" There are only two closing tags
syn match hscEndTag "</$\(if\|macro\)>"

syn region hscMacro start="<$macro\>" end="</$macro>" contains=TOP
syn region hscIfTagR matchgroup=hscIfTag start="<$if\>" end=">" contains=hscAttr
syn match hscElseTag "<$else>"
syn match hscElseifTag "<$elseif>"

" Macros defined by HSC, may contain underscores
syn region  hscMacroR matchgroup=hscMacro start="<\w\+\>" end=">" contains=hscAttr

" All tags together
syn cluster hscTag contains=hscNormalTagR,hscMacroTagR,hscDefTagR,hscIfR,hscElse,hscElseif,hscMacro


" Top Cluster
syn cluster hscTop contains=hscComment,hscVerbatim,@hscTag,hscMacro,hscIf

" Highlighting
hi def hscTag term=bold cterm=bold

HscHiLink hscComment Comment
HscHiLink hscVerbatim hscTag
hi link hscNormalTag hscTag
hi link hscSpecialTag hscTag
hi link hscNormalTag hscTag
hi link hscMacroTag hscTag
hi link hscDefTag hscTag
hi link hscEndTag hscTag
hi link hscIfTag hscTag
hi link hscElseifTag hscTag
hi link hscElseTag hscTag
hi link hscOperator Operator
hi link hscAttr Type
hi link hscType Type
hi link hscString htmlString

let b:current_syntax = "htmlhsc"

if main_syntax == 'htmlhsc'
  unlet main_syntax
endif
